pub struct ArchKitClient { /* private fields */ }Expand description
The smallest reusable Arch client, currently limited to node health.
Implementations
Sourceimpl ArchKitClient
impl ArchKitClient
Sourcepub fn new(rpc_url: impl Into<String>) -> Result<Self, ArchKitError>
pub fn new(rpc_url: impl Into<String>) -> Result<Self, ArchKitError>
Create a client for an Arch JSON-RPC endpoint.
Sourcepub fn health(&self) -> Result<HealthStatus, ArchKitError>
pub fn health(&self) -> Result<HealthStatus, ArchKitError>
Check that the node is ready and produces a new block during the observation window.